#
# spec file for package kubectl-cnpg
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kubectl-cnpg
Version:        1.25.1
Release:        1.3
Summary:        Manage PostgreSQL clusters built using CloudNativePG
License:        Apache-2.0
URL:            https://github.com/cloudnative-pg/cloudnative-pg
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
CloudNativePG provides a plugin for kubectl to manage a cluster in Kubernetes.

Documentation is at:
https://cloudnative-pg.io/documentation/1.23/kubectl-plugin

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1 -n %{name}-%{version}

%build
# hash will be shortened by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/cloudnative-pg/cloudnative-pg/pkg/versions.buildVersion=v%{version} \
   -X github.com/cloudnative-pg/cloudnative-pg/pkg/versions.buildCommit=${COMMIT_HASH:0:8} \
   -X github.com/cloudnative-pg/cloudnative-pg/pkg/versions.buildDate=${BUILD_DATE}" \
   -o bin/%{name} ./cmd/%{name}/

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%check

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Sat Mar  1 2025 opensuse_buildservice@ojkastl.de
- Update to version 1.25.1:
  https://github.com/cloudnative-pg/cloudnative-pg/releases/tag/v1.25.1
  Changes related to the kubectl plugin:
  * Restored functionality of the promote plugin command. (#6476)
  * Enhanced kubectl cnpg report --logs <cluster> to collect logs
    from all containers, including sidecars. (#6636)
  * Ensured pgbench jobs can run when a Cluster uses an
    ImageCatalog. (#6868)
* Mon Dec 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.25.0:
  * Version tag to 1.25.0 (#6443)
  * docs: upgrade info to 1.25.0 (#6442)
  * docs: Release notes for 1.24.2 and 1.23.6 (#6438)
  * docs: Release notes for 1.25.0, 1.24.2, 1.23.6 (#6424)
  * chore: remove PluginConfigurationList type (#6431)
  * chore: remove ExternalClusterList type (#6426)
  * ci: stop testing Postgres 12 (#6425)
  * fix(deps): update module github.com/jackc/pgx/v5 to v5.7.2
    (main) (#6416)
  * docs: fix genref config (#6422)
  * feat: check the number of spec.schedule fields (#5396)
* Mon Dec 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.24.2:
  * Version tag to 1.24.2 (#6441)
  * fix(docs): spellcheck
  * docs: Release notes for 1.24.2 and 1.23.6 (#6438)
  * chore: remove PluginConfigurationList type (#6431)
  * fix(deps): update module github.com/jackc/pgx/v5 to v5.7.2
    (release-1.24) (#6419)
  * docs: fix genref config (#6422)
  * feat: check the number of spec.schedule fields (#5396)
  * chore(deps): update dependency kubernetes-csi/external-attacher
    to v4.8.0 (release-1.24) (#6407)
  * fix(deps): update module github.com/onsi/ginkgo/v2 to v2.22.1
    (release-1.24) (#6406)
  * chore(deps): update operator framework (release-1.24) (#6399)
  * fix(deps): update module
    github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring
    to v0.79.2 (release-1.24) (#6388)
  * chore: add missing labels in container images (#6377)
  * fix(roles): properly quote inRoles in SQL statements (#6346)
  * fix(deps): update kubernetes packages to v0.32.0 (release-1.24)
    (#6383)
  * fix(deps): update github.com/cloudnative-pg/machinery digest to
    2807bc8 (release-1.24) (#6376)
  * chore(deps): update helm/kind-action action to v1.11.0
    (release-1.24) (#6373)
  * chore(deps): update kindest/node docker tag to v1.32.0
    (release-1.24) (#6369)
  * feat: Public Cloud K8S versions update (#6316)
  * fix(deps): update github.com/cloudnative-pg/cnpg-i digest to
    cbc4287 (release-1.24) (#6356)
  * chore(deps): update dependency kubernetes-sigs/kind to v0.26.0
    (release-1.24) (#6360)
  * refactor: align with api structure in main
  * fix: use optimistic locking when updating conditions (#6328)
  * fix: key collision in structured logs (#6324)
  * chore(deps): update kubernetes csi (release-1.24) (#6353)
  * fix(deps): update github.com/cloudnative-pg/barman-cloud digest
    to 134c7de (release-1.24) (#6348)
  * chore(deps): update agilepathway/pull-request-label-checker
    docker tag to v1.6.60 (release-1.24) (#6342)
  * fix(deps): update all non-major go dependencies (release-1.24)
    (#6336)
  * fix(deps): update kubernetes patches (release-1.24) (#6250)
  * chore(refactor): isolate plugin loading function (#6312)
  * fix: deadlock when a plugin is used multiple times (#6309)
  * fix: panic recovering from an external server with no backup
    configuration (#6300)
  * chore: update the release script to better handle RC releases
    (#6301)
  * docs: heading level in (#3806)
  * docs: clarify behavior of primaryUpdateStrategy for
    single-instance clusters (#5001)
  * test: make sure we test port correctness for services (#4934)
  * feat: Public Cloud K8S versions update (#6263)
  * feat(plugin): set `User-Agent` in HTTP requests (#6153)
  * test(e2e): AssertConnection must retry before failing (#6293)
  * feat: add `cnpg.io/userType` label to generated secrets (#4392)
  * fix(deps): update github.com/cloudnative-pg/barman-cloud digest
    to 711113b (release-1.24) (#6288)
  * chore(e2e): Separate forward connection from psql connection
    (#5898)
  * chore(plugin): improve getting instance status from pod error
    message (#6092)
  * docs: define RPO and RTO (#6239)
  * chore(lint): spellcheck word list (#6290)
  * fix(plugin): avoid displaying physical backups block when empty
    (#5998)
  * docs: add a sample file for Scaleway object storage (#6143)
  * fix(bootstrap): clean up the WAL volume before initializing a
    cluster (#6265)
  * feat(probes): enable customization of startup, liveness, and
    readiness probes (#6266)
  * fix(plugin): pass context in `psql` command (#6257)
  * fix: eliminate redundant Cluster status updates with image
    catalog (#6277)
  * fix: correct path for partial wal archiver (#6255)
  * fix: ensure orphan services are reconciled after restoring a
    cluster (#5379)
  * chore: improve `TryInvokeQuitEndpoint` logging (#5355)
  * docs(plugin): standardize the `CLUSTER` argument in plugin
    commands (#6253)
  * fix(pooler): set libpq environment variables in PgBouncer pods
    (#6247)
  * chore: make cnpg plugin commands compatible with OLM (#6213)
  * fix(docs): add default rule for PgBouncer in `pg_hba` (#6175)
  * chore: remove unknown fields and improve CSV specs (#6107)
  * doc: clarify usage of endpointCA field with object store
    (#5537)
  * fix: add `PhaseUnrecoverable` when no PVCs exist (#6170)
  * chore: add `lint-fix` to the Makefile commands (#6226)
  * fix(initdb): ensure `primary_slot_name` is empty on a primary
    (#6219)
  * chore(docs): template for release notes for a new minor (#6229)
  * fix: ensure former primary WALs are flushed before resyncing
    (#6141)
  * docs: update join slack link (#6217)
  * fix(deps): update kubernetes patches (release-1.24) (#6209)
  * docs: clarify support for PostgreSQL 17 (#6202)
  * chore(deps): update dependency golangci/golangci-lint to
    v1.62.2 (release-1.24) (#6197)
  * fix(linter): prepare code for golangci-lint 1.62.2 (#6198)
  * chore(deps): update xt0rted/pull-request-comment-branch action
    to v3 (release-1.24) (#6193)
  * chore(deps): update operator framework to v1.38.0
    (release-1.24) (#6189)
  * chore(deps): update dependency rook/rook to v1.15.6
    (release-1.24) (#6185)
  * chore(deps): update cloudnative-pg/ciclops action to v1.3.1
    (release-1.24) (#6180)
  * fix(deps): update all non-major go dependencies (release-1.24)
    (#6166)
  * docs: add Obmondo to `ADOPTERS.md` (#6162)
  * docs: add Docaposte to ADOPTERS.md (#6145)
  * feat: update default PostgreSQL version to 17.2 (#6018)
  * feat: Public Cloud K8S versions update (#6129)
  * docs: add Novo Nordisk as a CloudNativePG adopter (#6142)
  * docs: add Akamai Technologies as an adopter (#6140)
  * chore(perf): Use controller-runtime pprof server (#6000)
  * chore: simplify tablespaces interfaces for testing (#5635)
  * chore(deps): update all non-major go dependencies
    (release-1.24) (#6128)
  * chore(deps): update dependency
    vmware-tanzu/velero-plugin-for-aws to v1.11.0 (release-1.24)
    (#6124)
  * fix(tests): update the way we check the EKS versions (#6101)
  * chore(deps): update dependency vmware-tanzu/velero to v1.15.0
    (release-1.24) (#6105)
  * chore(deps): update dependency kubernetes-sigs/kind to v0.25.0
    (release-1.24) (#6098)
  * chore(deps): update rajatjindal/krew-release-bot action to
    v0.0.47 (release-1.24) (#6085)
  * chore(deps): update kindest/node docker tag to v1.31.2
    (release-1.24) (#6078)
  * chore(security): improve Snyk scan (#6059)
  * chore(deps): update dependency rook/rook to v1.15.5
    (release-1.24) (#6073)
  * chore(deps): update dependency go to v1.23.3 (release-1.24)
    (#6053)
  * fix: correct transaction code and resolve non deterministic
    role apply (#6064)
  * fix(test): avoid checking permissions in cloud services (#6062)
  * chore(deps): update spellcheck to v0.45.0 (release-1.24)
    (#6042)
  * refactor: simplify replication slots code, clarify tests
    (#6003)
  * docs(kubectl-plugin): update formatting and version (#6026)
  * refactor: bring role reconciler Postgres functions in line with
    other reconcilers (#5958)
  * fix(deps): update kubernetes patches (release-1.24) (#6037)
  * chore(deps): update module github.com/goreleaser/goreleaser to
    v2.4.4 (release-1.24) (#6022)
  * fix(plugin): check for empty pod list in "cnpg psql" (#6023)
  * chore: ensure the proper version of OLM tools is being executed
    (#5361)
  * fix(docs): minor doc change about snapshot images (#5357)
  * fix(pooler): ensure SA and RBAC are reconciled before
    deployment (#5344)
  * feat: Public Cloud K8S versions update (#5938)
  * fix(deps): update module
    github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring
    to v0.78.0 (release-1.24) (#6013)
  * fix(deps): update all non-major go dependencies (release-1.24)
    (#6008)
  * chore(deps): update module sigs.k8s.io/controller-tools to
    v0.16.5 (release-1.24) (#5993)
  * fix(webhook): validate the number of `synchronous` replicas
    (#5985)
  * fix(docs): properly indent a block in logging page (#5970)
  * chore(deps): update spellcheck to v0.44.0 (release-1.24)
    (#5990)
  * chore(config): migrate renovate config (#5986)
  * docs: add permissions required by kubectl CNPG plugin (#5829)
  * chore(deps): update dependency
    operator-framework/operator-registry to v1.48.0 (release-1.24)
    (#5981)
  * fix(deps): update module sigs.k8s.io/controller-runtime to
    v0.19.1 (release-1.24) (#5962)
  * fix(plugin): improve plugin errors (#5836)
  * fix(metrics): handle FIRST keyword in synchronousStandbyNames
    parsing (#5955)
  * docs: add Walkbase to `ADOPTERS.md` (#5951)
  * docs: fix minor issues (#5903)
  * test: improve unit tests and add race condition detection
    (#5936)
  * fix(deps): update kubernetes patches to v0.31.2 (release-1.24)
    (#5935)
  * fix(plugin): handle multiple containers in `kubectl cnpg logs`
    (#5931)
  * test: Updated Postgres versions used in E2E tests (#5863)
  * test: remove redundant log capture in tablespace tests (#5781)
  * feat: Public Cloud K8S versions update (#5918)
  * chore(tests): Refactored backup and restore tests by separating
    backend-specific logic (#5735)
  * fix(deps): update module
    github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring
    to v0.77.2 (release-1.24) (#5925)
  * fix(deps): update github.com/cloudnative-pg/cnpg-i digest to
    8d61352 (release-1.24) (#5916)
  * fix(deps): update github.com/cloudnative-pg/barman-cloud digest
    to 44f56f7 (release-1.24) (#5915)
  * test: replace temp directory handling with GinkgoT().TempDir()
    (#5914)
  * chore(deps): update jonasbn/github-action-spellcheck docker tag
    to v0.43.1 (release-1.24) (#5911)
  * test: improve handling of release directory in unit tests
    (#5901)
  * test(e2e): refactor assertions to create, insert and validate
    data (#5759)
  * ci: properly quote options in bug issue templates (#5897)
  * chore(deps): update dependency rook/rook to v1.15.4
    (release-1.24) (#5896)
  * chore(deps): update rojopolis/spellcheck-github-actions action
    to v0.43.1 (release-1.24) (#5889)
  * ci: collect apiserver audit logs (#5879)
  * test(e2e): prevent namespace deletion timeout (#5854)
  * chore(deps): update module sigs.k8s.io/kustomize/kustomize/v5
    to v5.5.0 (release-1.24) (#5872)
  * chore(deps): update dependency
    redhat-openshift-ecosystem/openshift-preflight to v1.10.2
    (release-1.24) (#5869)
  * fix(deps): update all non-major go dependencies (release-1.24)
    (#5740)
  * fix(docs): update header for 1.24 upgrade procedure (#5862)
* Wed Oct 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.24.1:
  * feat(plugin): add `logs pretty` command (#5779)
  * fix(plugin): collect logs from sidecars with `logs cluster`
    (#5826)
  * chore(plugin): organise plugin commands into groups (#5796)
  * fix(plugin): ensure pgadmin4 has a writable home directory
    (#5800)
  * feat(plugin): compact output of `status` command (#5765)
  * fix(plugin): avoid jamming JSON logs with `logs` command
    (#5775)
  * fix(backup,plugin): keep plugin connection open while running a
    backup (#5726)
  * fix(backup,plugin): add `BackupStartingCondition` condition to
    cluster while using the plugin method (#5697)
  * fix(plugin): handle `potential` sync in `status` command
    (#5533)
  * fix(plugin): restrict `cnpg destroy` job deletion to the
    specified namespace (#5372)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.24.0:
  kubectl-plugin-related changes:
  * feat(plugin): `--control-plane` option with `install generate`
    (#5271)
  * fix(plugin): delete jobs with `destroy` command (#5298)
  * feat(plugin): enable customizing the remote dbname in
    subscriptions and publications (#5113)
  * feat(plugin): display `demotionToken` in `cnpg status` (#5149)
  * feat: Add plugin method to ScheduledBackup (#4424)
  * fix(plugin): handle errors during the `status` command
    execution (#4882)
  * feat(plugin): support color control via  flags and TTY
    detection (#4775)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.23.4:
  kubectl-plugin-related changes:
  * feat(plugin): `--control-plane` option with `install generate`
    (#5271)
  * fix(plugin): delete jobs with `destroy` command (#5298)
  * feat: update default PostgreSQL version to 16.4 (#5262)
* Tue Jul 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.23.3:
  Changes related to the kubectl plugin:
  * Properly handle errors during the status command execution.
  * Support TLS in the status command (#4915).
* Thu Jun 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.23.2:
  * Enhancements:
  - Enabled configuration of standby-sensitive parameters during
    recovery using a physical backup (#4564)
  - Enabled the configuration of the liveness probe timeout via
    the .spec.livenessProbeTimeout option (#4719)
  - cnpg plugin for kubectl:
  * Enhanced support for ANSI colors in the plugin by adding
    the --color option, which accepts always, never, and auto
    (default) as values (#4775)
  * The plugin is now available on Homebrew for macOS users
    (#4602)
  * Fixes:
  - Prevented fenced instances from entering an unnecessary loop
    and consuming all available CPU (#4625)
  - Resolved an issue where the instance manager on the primary
    would indefinitely wait for the instance to start after
    encountering a failure following a stop operation (#4434)
  - Fixed an issue where the interaction between
    hot_standby_feedback and managed cluster-level replication
    slots was preventing the autovacuum from operating correctly;
    this issue was causing disk space to remain occupied by dead
    tuples (#4811)
  - Fixed a panic in the backup controller that occurred when pod
    container statuses were missing (#4765)
  - Prevented unnecessary shutdown of the instance manager
    (#4670)
  - Prevented unnecessary reloads of PostgreSQL configuration
    when unchanged (#4531)
  - Prevented unnecessary reloads of the ident map by ensuring a
    consistent and unique method of writing its content (#4648)
  - Avoided conflicts during phase registration by patching the
    status of the resource instead of updating it (#4637)
  - Implemented a timeout when restarting PostgreSQL and lifting
    fencing (#4504)
  - Ensured that a replica cluster is restarted after promotion
    to properly set the archive mode (#4399)
  - Removed an unneeded concurrent keep-alive routine that was
    causing random failures in volume snapshot backups (#4768)
  - Ensured correct parsing of the additional rows field returned
    when the pgaudit.log_rows option was enabled, preventing
    audit logs from being incorrectly routed to the normal log
    stream (#4394)
  - cnpg plugin for kubectl:
  * Resolved an issue with listing PDBs using the cnpg status
    command (#4530)
  * Changes
    Default operand image set to PostgreSQL 16.3 (#4584)
    Removed all RBAC requirements on namespace objects (#4753)
* Wed May  8 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kubectl-cnpg: plugin to manage PostgreSQL clusters
  built using CloudNativePG
